NEP Python library
==================

NEP+ is a *comprehensive* software platform (i.e., that provides a variety of functionalities) designed to facilitate the integration and design of interactive applications with both physical and digital agents.

NEP+ is a *holistic* software platform designed to empower users and developers with different backgrounds and preferences.

- Provides user-friendly interfaces that are accessible to end-users and advanced tools for experienced developers.
- Different research communities can adopt it, as interfaces and core libraries support different programming languages and operating systems.

The main functionality of NEP+ is to help and support in the design heterogeneous software architectures (i.e., complex applications composed of several modules developed over different programming languages, running on different operating systems, and performing different tasks).

Official website: https://enrique-coronado.gitbook.io/nep-docs/


